@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -152,3 +152,7 @@ class TailboneCorePosProvider(TailboneProvider):
                 },
             },
         }
+
+    def make_integration_menu(self, request, **kwargs):
+        from tailbone_corepos.menus import make_corepos_menu
+        return make_corepos_menu(request)
