@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -39,5 +39,12 @@ class TableSyncRuleView(CoreOfficeMasterView):
     route_prefix = 'corepos.table_sync_rules'
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    TableSyncRuleView = kwargs.get('TableSyncRuleView', base['TableSyncRuleView'])
     TableSyncRuleView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
