@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,42 +24,34 @@
 Subdepartment Views
 """
 
-from rattail_corepos.config import core_office_url
-
-from tailbone.views import subdepartments as base
+from tailbone.views import ViewSupplement
 
 
-class SubdepartmentView(base.SubdepartmentView):
+class SubdepartmentViewSupplement(ViewSupplement):
     """
-    Master view for the Subdepartment class.
+    Subdepartment view supplement for CORE integration
     """
+    route_prefix = 'subdepartments'
+
     labels = {
         'corepos_number': "CORE-POS Number",
     }
 
-    @property
-    def form_fields(self):
-        fields = super(SubdepartmentView, self).form_fields
-        return fields + [
-            'corepos_number',
-        ]
-
-    def query(self, session):
-        query = super(SubdepartmentView, self).query(session)
-        model = self.rattail_config.get_model()
+    def get_grid_query(self, query):
+        model = self.model
         return query.outerjoin(model.CoreSubdepartment)
 
     def configure_grid(self, g):
-        super(SubdepartmentView, self).configure_grid(g)
-        model = self.rattail_config.get_model()
+        model = self.model
         g.set_filter('corepos_number', model.CoreSubdepartment.corepos_number)
 
+    def configure_form(self, f):
+        f.append('corepos_number')
+
     def get_version_child_classes(self):
-        model = self.rattail_config.get_model()
-        return super(SubdepartmentView, self).get_version_child_classes() + [
-            model.CoreSubdepartment,
-        ]
+        model = self.model
+        return [model.CoreSubdepartment]
 
 
 def includeme(config):
-    SubdepartmentView.defaults(config)
+    SubdepartmentViewSupplement.defaults(config)
